==> inlmisc_0.2.6.tar.gz: inlmisc/README.md <==
# inlmisc

[![Travis Build Status](https://travis-ci.org/USGS-R/inlmisc.svg?branch=master)](https://travis-ci.org/USGS-R/inlmisc)
[![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/pvcq1jsgabqx61ah?svg=true)](https://ci.appveyor.com/project/jfisher-usgs/inlmisc)
[![Coverage Status](https://coveralls.io/repos/github/USGS-R/inlmisc/badge.svg?branch=master)](https://coveralls.io/github/USGS-R/inlmisc?branch=master)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/inlmisc)](https://CRAN.R-project.org/package=inlmisc)
[![](https://cranlogs.r-pkg.org/badges/inlmisc?color=brightgreen)](https://CRAN.R-project.org/package=inlmisc)
[![CC0](https://img.shields.io/badge/license-CC0--1.0-brightgreen.svg)](https://creativecommons.org/publicdomain/zero/1.0/)

## Overview

The [R](https://www.r-project.org/) package **inlmisc** is a collection of functions for creating high-level graphics,
performing raster-based analysis, processing [MODFLOW](https://water.usgs.gov/ogw/modflow/)-based models, and overlaying multi-polygon objects.
Used to support packages and scripts written by researchers at the United States Geological Survey (USGS)
[Idaho National Laboratory Project Office](http://id.water.usgs.gov/INL/ "INL Project Office").

## Install

You can install the stable version from [CRAN](https://CRAN.R-project.org/package=inlmisc) using the following command:

```r
install.packages("inlmisc")
```

Or use **devtools** to install the development version from GitHub.

```r
devtools::install_github("USGS-R/inlmisc")
```

## Bugs

Please consider reporting bugs and asking questions on the [Issues page](https://github.com/USGS-R/inlmisc/issues).

## Disclaimer

This software is in the public domain because it contains materials that originally came from the USGS,
an agency of the United States Department of Interior.
For more information, see the
[official USGS copyright policy](https://www2.usgs.gov/visual-id/credit_usgs.html "official USGS copyright policy").

Although this software program has been used by the USGS, no warranty, expressed or implied,
is made by the USGS or the U.S. Government as to the accuracy and functioning of the program and related program material nor shall the fact of distribution constitute any such warranty,
and no responsibility is assumed by the USGS in connection therewith.

This software is provided "AS IS."

==> inlmisc_0.3.0.tar.gz: inlmisc/README.md <==
# inlmisc

[![Travis Build Status](https://travis-ci.org/USGS-R/inlmisc.svg?branch=master)](https://travis-ci.org/USGS-R/inlmisc)
[![AppVeyor Build Status](https://ci.appveyor.com/api/projects/status/pvcq1jsgabqx61ah?svg=true)](https://ci.appveyor.com/project/jfisher-usgs/inlmisc)
[![Coverage Status](https://coveralls.io/repos/github/USGS-R/inlmisc/badge.svg?branch=master)](https://coveralls.io/github/USGS-R/inlmisc?branch=master)
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/inlmisc)](https://CRAN.R-project.org/package=inlmisc)
[![](https://cranlogs.r-pkg.org/badges/inlmisc?color=brightgreen)](https://CRAN.R-project.org/package=inlmisc)
[![CC0](https://img.shields.io/badge/license-CC0--1.0-brightgreen.svg)](https://creativecommons.org/publicdomain/zero/1.0/)
[![USGS Category](https://img.shields.io/badge/USGS-Support-yellow.svg)](https://owi.usgs.gov/R/packages.html#support)

## Overview

The [R](https://www.r-project.org/) package **inlmisc** is a collection of functions for creating high-level graphics,
performing raster-based analysis, processing [MODFLOW](https://water.usgs.gov/ogw/modflow/)-based models, etc.
Used to support packages and scripts written by researchers at the United States Geological Survey (USGS)
[Idaho National Laboratory Project Office](http://id.water.usgs.gov/INL/ "INL Project Office").

## Install

You can install the stable version from [CRAN](https://CRAN.R-project.org/package=inlmisc) using the following command:

```r
install.packages("inlmisc", dependencies = TRUE)
```

Or use **devtools** to install the development version from GitHub.

```r
devtools::install_github("USGS-R/inlmisc")
```

## Bugs

Please consider reporting bugs and asking questions on the [Issues page](https://github.com/USGS-R/inlmisc/issues).

## Disclaimer

This software is in the public domain because it contains materials that originally came from the USGS,
an agency of the United States Department of Interior.
For more information, see the
[official USGS copyright policy](https://www2.usgs.gov/visual-id/credit_usgs.html "official USGS copyright policy").

Although this software program has been used by the USGS, no warranty, expressed or implied,
is made by the USGS or the U.S. Government as to the accuracy and functioning of the program and related program material nor shall the fact of distribution constitute any such warranty,
and no responsibility is assumed by the USGS in connection therewith.

This software is provided "AS IS."
